==> test-envelope-ui-0.0.32.tgz: package/es/button/button.js <==
var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _templateObject = _taggedTemplateLiteralLoose(['\n  &&& {\n    line-height: inherit;\n    cursor: inherit;\n    color: ', ';\n  }\n'], ['\n  &&& {\n    line-height: inherit;\n    cursor: inherit;\n    color: ', ';\n  }\n']),
    _templateObject2 = _taggedTemplateLiteralLoose(['\n  font-size: 1em;\n  padding: ', ';\n  margin: 0;\n  display: inline-block;\n  cursor: pointer;\n  border-radius: 5px;\n  margin: 1px 2px;\n  line-height: ', ';\n  border: 0;\n  background-color: ', ';\n\n  &:hover {\n    margin: 0 1px;\n    border: 1px solid ', ';\n    box-shadow: rgba(0, 0, 0, 0.1) 0px 2px 26px,\n      rgba(0, 0, 0, 0.075) 0px 2px 8px;\n    &:hover ', ' {\n      color: ', ';\n    }\n  }\n'], ['\n  font-size: 1em;\n  padding: ', ';\n  margin: 0;\n  display: inline-block;\n  cursor: pointer;\n  border-radius: 5px;\n  margin: 1px 2px;\n  line-height: ', ';\n  border: 0;\n  background-color: ', ';\n\n  &:hover {\n    margin: 0 1px;\n    border: 1px solid ', ';\n    box-shadow: rgba(0, 0, 0, 0.1) 0px 2px 26px,\n      rgba(0, 0, 0, 0.075) 0px 2px 8px;\n    &:hover ', ' {\n      color: ', ';\n    }\n  }\n']);

function _objectWithoutProperties(obj, keys) { var target = {}; for (var i in obj) { if (keys.indexOf(i) >= 0) continue; if (!Object.prototype.hasOwnProperty.call(obj, i)) continue; target[i] = obj[i]; } return target; }

function _taggedTemplateLiteralLoose(strings, raw) { strings.raw = raw; return strings; }

import React from 'react';
import styled, { ThemeContext } from 'styled-components';
import PropTypes from 'prop-types';

import { themeProps, clutchd } from '../themed/themes';
import { getTheme } from '../themed/utils';

import Typography from '../typography';
var Text = Typography.Text;


var propTypes = {
  theme: themeProps,
  size: PropTypes.oneOf(['xs', 'sm', 'md', 'lg', 'xl']),
  space: PropTypes.oneOf(['xs', 'sm', 'md', 'lg', 'xl'])
};

var defaultProps = {
  theme: clutchd.theme,
  size: 'md',
  space: 'md'
};

// styles
var StyledButtonText = styled(Text)(_templateObject, function (props) {
  return props.theme.colors.light;
});

var StyledButton = styled.button(_templateObject2, function (props) {
  return props.theme.spaces[props.space];
}, function (props) {
  return props.theme.sizes[props.size];
}, function (props) {
  return props.theme.colors.dark;
}, function (props) {
  return props.theme.colors.primary;
}, StyledButtonText, function (props) {
  return props.theme.colors.primary;
});

var Button = function Button(_ref) {
  var theme = _ref.theme,
      loading = _ref.loading,
      children = _ref.children,
      props = _objectWithoutProperties(_ref, ['theme', 'loading', 'children']);

  var currentTheme = getTheme(ThemeContext, theme);

  return React.createElement(
    StyledButton,
    _extends({ theme: currentTheme }, props),
    loading ? {
      /* add loading icon/skeleton component */
    } : React.createElement(
      StyledButtonText,
      _extends({ theme: currentTheme }, props),
      children
    )
  );
};

Button.propTypes = process.env.NODE_ENV !== "production" ? propTypes : {};
Button.defaultProps = defaultProps;

export default Button;

==> test-envelope-ui-0.0.40.tgz: package/es/button/button.js <==
var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _templateObject = _taggedTemplateLiteralLoose(['\n  &&& {\n    line-height: inherit;\n    cursor: inherit;\n    color: ', ';\n  }\n'], ['\n  &&& {\n    line-height: inherit;\n    cursor: inherit;\n    color: ', ';\n  }\n']),
    _templateObject2 = _taggedTemplateLiteralLoose(['\n  font-size: 1em;\n  padding: ', ';\n  margin: 0;\n  display: inline-block;\n  cursor: pointer;\n  border-radius: 5px;\n  margin: 1px 2px;\n  line-height: ', ';\n  border: 0;\n  background-color: ', ';\n\n  &:hover {\n    margin: 0 1px;\n    border: 1px solid ', ';\n    box-shadow: rgba(0, 0, 0, 0.1) 0px 2px 26px,\n      rgba(0, 0, 0, 0.075) 0px 2px 8px;\n    &:hover ', ' {\n      color: ', ';\n    }\n  }\n'], ['\n  font-size: 1em;\n  padding: ', ';\n  margin: 0;\n  display: inline-block;\n  cursor: pointer;\n  border-radius: 5px;\n  margin: 1px 2px;\n  line-height: ', ';\n  border: 0;\n  background-color: ', ';\n\n  &:hover {\n    margin: 0 1px;\n    border: 1px solid ', ';\n    box-shadow: rgba(0, 0, 0, 0.1) 0px 2px 26px,\n      rgba(0, 0, 0, 0.075) 0px 2px 8px;\n    &:hover ', ' {\n      color: ', ';\n    }\n  }\n']);

function _objectWithoutProperties(obj, keys) { var target = {}; for (var i in obj) { if (keys.indexOf(i) >= 0) continue; if (!Object.prototype.hasOwnProperty.call(obj, i)) continue; target[i] = obj[i]; } return target; }

function _taggedTemplateLiteralLoose(strings, raw) { strings.raw = raw; return strings; }

import React from 'react';
import styled, { ThemeContext } from 'styled-components';
import PropTypes from 'prop-types';

import { clutchd, themeProps } from '../style/themes';
import { getTheme } from '../style/utils';

import Typography from '../typography';
var Text = Typography.Text;


var propTypes = {
  theme: themeProps,
  size: PropTypes.oneOf(['xs', 'sm', 'md', 'lg', 'xl']),
  space: PropTypes.oneOf(['xs', 'sm', 'md', 'lg', 'xl'])
};

var defaultProps = {
  theme: clutchd,
  size: 'md',
  space: 'md'
};

// styles
var StyledButtonText = styled(Text)(_templateObject, function (props) {
  return props.theme.colors.light;
});

var StyledButton = styled.button(_templateObject2, function (props) {
  return props.theme.spaces[props.space];
}, function (props) {
  return props.theme.sizes[props.size];
}, function (props) {
  return props.theme.colors.dark;
}, function (props) {
  return props.theme.colors.primary;
}, StyledButtonText, function (props) {
  return props.theme.colors.primary;
});

var Button = function Button(_ref) {
  var theme = _ref.theme,
      loading = _ref.loading,
      children = _ref.children,
      props = _objectWithoutProperties(_ref, ['theme', 'loading', 'children']);

  var currentTheme = getTheme(ThemeContext, theme);

  return React.createElement(
    StyledButton,
    _extends({ theme: currentTheme }, props),
    loading ? {
      /* add loading icon/skeleton component */
    } : React.createElement(
      StyledButtonText,
      _extends({ theme: currentTheme }, props),
      children
    )
  );
};

Button.propTypes = process.env.NODE_ENV !== "production" ? propTypes : {};
Button.defaultProps = defaultProps;

export default Button;
